@@ -65,10 +65,16 @@ def enable_data_capture():
     def capture_qmi_response(event, obj, args, return_value):
         logger.debug("{!s}(obj={!r}, args={!r}, return_value={!r})".format(
             event, obj, args, return_value))
+
+        topology = _get_solver_topology(obj)
+        if topology['type'] not in SUPPORTED_SOLVER_TOPOLOGY_TYPES:
+            logger.error('Solver topology {!r} not supported.'.format(topology))
+            return
+
         try:
             storage.add_problem(problem=args, solver=obj, response=return_value)
         except Exception as e:
-            logger.error('Failed to store problem with: %r', e)
+            logger.error('Failed to store problem: %r', e)
 
     # subscribe to problems sampled and results returned in the cloud client
     add_handler('after_sample', capture_qmi_response)
@@ -305,6 +311,7 @@ def _problem_stats(response=None, sampleset=None, embedding_context=None):
 def _details_dict(response):
     return {
         "id": response.id,
+        "label": response.label,
         "status": response.remote_status,
         "solver": response.solver.id,
         "type": response.problem_type,
@@ -396,7 +403,7 @@ def from_qmi_response(problem, response, embedding_context=None, warnings=None,
 
     solutions = list(map(itemsgetter(*active_variables), response['solutions']))
     energies = response['energies']
-    num_occurrences = response.occurrences
+    num_occurrences = response.num_occurrences
     num_variables = solver.num_qubits
     timing = response.timing
 
@@ -493,7 +500,7 @@ def from_bqm_response(bqm, embedding_context, response, warnings=None,
 
     solutions = list(map(itemsgetter(*active_variables), response['solutions']))
     energies = response['energies']
-    num_occurrences = response.occurrences
+    num_occurrences = response.num_occurrences
     num_variables = solver.num_qubits
     timing = response.timing
 
@@ -727,7 +734,8 @@ def from_bqm_sampleset(bqm, sampleset, sampler, embedding_context=None,
         "details": {
             "id": problem_id,
             "type": problem_type,
-            "solver": solver.id
+            "solver": solver.id,
+            "label": sampleset.info.get('problem_label'),
         },
         "data": _problem_dict(solver_id, problem_type, problem_data, params, problem_stats),
         "answer": _answer_dict(solutions, active_variables, energies, num_occurrences, timing, num_variables),
@@ -794,6 +802,7 @@ def from_objects(*args, **kwargs):
         response.result()
 
     # read problem_id from sampleset or response
+    # TODO: resolve sampleset/response if they are not resolved yet?
     if problem_id is None and sampleset is not None:
         problem_id = sampleset.info.get('problem_id')
     if problem_id is None and response is not None:
@@ -842,4 +851,5 @@ def from_objects(*args, **kwargs):
 
     raise ValueError(
         "invalid combination of arguments provided: if data capture not "
-        "enabled, problem/response/solver/etc have to be explicitly specified")
+        "enabled, problem/response/solver have to be specified; "
+        "also, make sure a structured problem is being inspected")
